summaryrefslogtreecommitdiff
path: root/uvim/src/nbdebug.c
diff options
context:
space:
mode:
authorMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-03 22:21:25 +0300
committerMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-04 00:23:03 +0300
commit2eae5db069dc171f74cd863487655f6a88e5384d (patch)
tree2d9d05e09978a2a44acbfbb8d651f240df3ca052 /uvim/src/nbdebug.c
parent473d922faed49241a5d29d9e37dc4819cd512006 (diff)
downloadProject-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.tar.gz
Project-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.zip
NOISSUE rebrand vim to MNV's not Vim
Signed-off-by: Mehmet Samet Duman <yongdohyun@projecttick.org>
Diffstat (limited to 'uvim/src/nbdebug.c')
-rw-r--r--uvim/src/nbdebug.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/uvim/src/nbdebug.c b/uvim/src/nbdebug.c
index 58fcad3ef8..10824ec63b 100644
--- a/uvim/src/nbdebug.c
+++ b/uvim/src/nbdebug.c
@@ -1,33 +1,33 @@
/* vi:set ts=8 sw=8 noet:
*
* VIM - Vi IMproved by Bram Moolenaar
* Visual Workshop integration by Gordon Prieur
*
* Do ":help uganda" in Vim to read copying and usage conditions.
* Do ":help credits" in Vim to see a list of people who contributed.
* See README.txt for an overview of the Vim source code.
*/
/*
* NetBeans Debugging Tools. What are these tools and why are they important?
* There are two main tools here. The first tool is a tool for delaying or
- * stopping gvim during startup. The second tool is a protocol log tool.
+ * stopping gmnv during startup. The second tool is a protocol log tool.
*
* The startup delay tool is called nbdebug_wait(). This is very important for
- * debugging startup problems because gvim will be started automatically from
+ * debugging startup problems because gmnv will be started automatically from
* netbeans and cannot be run directly from a debugger. The only way to debug
- * a gvim started by netbeans is by attaching a debugger to it. Without this
+ * a gmnv started by netbeans is by attaching a debugger to it. Without this
* tool all startup code will have completed before you can get the pid and
* attach.
*
* The second tool is a log tool.
*
* This code must have NBDEBUG defined for it to be compiled into vim/gvim.
*/
#ifdef NBDEBUG
-#include "vim.h"
+#include "mnv.h"
FILE *nb_debug = NULL;
u_int nb_dlevel = 0; // nb_debug verbosity level
@@ -40,9 +40,9 @@ static int errorHandler(Display *, XErrorEvent *);
#endif
/*
* nbdebug_wait - This function can be used to delay or stop execution of vim.
* It's normally used to delay startup while attaching a
- * debugger to a running process. Since NetBeans starts gvim
+ * debugger to a running process. Since NetBeans starts gmnv
* from a background process this is the only way to debug
* startup problems.
*/
@@ -63,11 +63,11 @@ nbdebug_wait(
{
sleep(atoi(getenv(wait_var)));
}
- else if (wait_flags & WT_WAIT && lookup("~/.gvimwait"))
+ else if (wait_flags & WT_WAIT && lookup("~/.gmnvwait"))
{
sleep(wait_secs > 0 && wait_secs < 120 ? wait_secs : 20);
}
- else if (wait_flags & WT_STOP && lookup("~/.gvimstop"))
+ else if (wait_flags & WT_STOP && lookup("~/.gmnvstop"))
{
int w = 1;
while (w)
@@ -147,7 +147,7 @@ errorHandler(
char buf[256];
XGetErrorText(dpy, err->error_code, msg, sizeof(msg));
- nbdbg("\n\nNBDEBUG Vim: X Error of failed request: %s\n", msg);
+ nbdbg("\n\nNBDEBUG MNV: X Error of failed request: %s\n", msg);
sprintf(buf, "%d", err->request_code);
XGetErrorDatabaseText(dpy,
@@ -1,33 +1,33 @@
/* vi:set ts=8 sw=8 noet:
*
- * VIM - Vi IMproved by Bram Moolenaar
+ * MNV - MNV is not Vim by Bram Moolenaar
* Visual Workshop integration by Gordon Prieur
*
@@ -1,33 +1,33 @@
* Visual Workshop integration by Gordon Prieur
*
- * Do ":help uganda" in Vim to read copying and usage conditions.
- * Do ":help credits" in Vim to see a list of people who contributed.
- * See README.txt for an overview of the Vim source code.
+ * Do ":help uganda" in MNV to read copying and usage conditions.
+ * Do ":help credits" in MNV to see a list of people who contributed.
+ * See README.txt for an overview of the MNV source code.
*/
/*
@@ -1,33 +1,33 @@
* The second tool is a log tool.
*
- * This code must have NBDEBUG defined for it to be compiled into vim/gvim.
+ * This code must have NBDEBUG defined for it to be compiled into mnv/gmnv.
*/
#ifdef NBDEBUG
@@ -40,9 +40,9 @@ static int errorHandler(Display *, XErrorEvent *);
#endif
/*
- * nbdebug_wait - This function can be used to delay or stop execution of vim.
+ * nbdebug_wait - This function can be used to delay or stop execution of mnv.
* It's normally used to delay startup while attaching a